==> kdenetwork-1.91.tar.bz2: kdenetwork-1.91/knode/kncleanupsettings.h <==
/***************************************************************************
                          kncleanupsettings.h  -  description
                             -------------------
    
    copyright            : (C) 2000 by Christian Thurner
    email                : cthurner@freepage.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   * 
 *                                                                         *
 ***************************************************************************/


#ifndef KNCLEANUPSETTINGS_H
#define KNCLEANUPSETTINGS_H

#include "knsettingswidget.h"
#include <qcheckbox.h>
#include <qspinbox.h>

class KNCleanupSettings : public KNSettingsWidget  {
	
	Q_OBJECT

	public:
		KNCleanupSettings(QWidget *p);
		~KNCleanupSettings();
		
		void init();
		void apply();
		
	protected:
		QCheckBox *folderCB, *groupCB, *thrCB;
		QSpinBox *folderDays, *groupDays, *readDays, *unreadDays;
		
	protected slots:
		void slotGroupCBtoggled(bool b);
		void slotFolderCBtoggled(bool b);
};

#endif

==> kdenetwork-2.0.1.tar.bz2: kdenetwork-2.0.1/knode/kncleanupsettings.h <==
/***************************************************************************
                          kncleanupsettings.h  -  description
                             -------------------
    
    copyright            : (C) 2000 by Christian Thurner
    email                : cthurner@freepage.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   * 
 *                                                                         *
 ***************************************************************************/


#ifndef KNCLEANUPSETTINGS_H
#define KNCLEANUPSETTINGS_H

#include "knsettingsdialog.h"

class QCheckBox;
class KIntSpinBox;
class QLabel;


class KNCleanupSettings : public KNSettingsWidget  {
  
  Q_OBJECT

  public:
    KNCleanupSettings(QWidget *p);
    ~KNCleanupSettings();
    
    void apply();
    
  protected:
    void init();
    QCheckBox *folderCB, *groupCB, *thrCB;
    KIntSpinBox *folderDays, *groupDays, *readDays, *unreadDays;
    QLabel *folderDaysL,*groupDaysL, *readDaysL, *unreadDaysL;
    
  protected slots:
    void slotGroupCBtoggled(bool b);
    void slotFolderCBtoggled(bool b);
};

#endif
